@@ -1,9 +1,10 @@
-
 def remove_barostat(system):
     """Remove MonteCarloBarostat if present"""
     fs = system.getForces()
     for i, f in enumerate(fs):
-        if type(f) == simtk.openmm.openmm.MonteCarloBarostat or \
-           type(f) == simtk.openmm.openmm.MonteCarloAnisotropicBarostat:
+        if (
+            type(f) == openmm.openmm.openmm.MonteCarloBarostat
+            or type(f) == openmm.openmm.openmm.MonteCarloAnisotropicBarostat
+        ):
             system.removeForce(i)
             return
